@@ -1,24 +1,22 @@
 # -*- coding: utf-8 -*-
 
-import tg, pylons
-from tg.util import no_warn
-from tg.controllers import TGController, RestController
-from tg.controllers.dispatcher import DispatchState
-from tg.decorators import expose, validate, override_template
-from routes import Mapper
-from routes.middleware import RoutesMiddleware
-from formencode import validators
 from webob import Response, Request
-from nose.tools import raises
 
-from tests.base import TestWSGIController, make_app, setup_session_dir, \
-                          teardown_session_dir
+from tg.controllers import TGController, RestController
+from tg.decorators import expose
+from tg.util import no_warn
+
+from tests.base import (
+    TestWSGIController, make_app, setup_session_dir, teardown_session_dir)
+
 
 def setup():
     setup_session_dir()
+
 def teardown():
     teardown_session_dir()
 
+
 def wsgi_app(environ, start_response):
     req = Request(environ)
     if req.method == 'POST':
@@ -43,11 +41,14 @@ class LookupController(TGController):
     def _lookup(self, a, *args):
         return LookupHelper(a), args
 
+
 class DeprecatedLookupController(TGController):
+
     @expose()
     def lookup(self, a, *args):
         return LookupHelper(a), args
 
+
 class LookupAlwaysHelper:
     """for testing _dispatch"""
 
@@ -65,13 +66,14 @@ class LookupAlwaysHelper:
         state.add_method(self.always, remainder)
         return state
 
-class LookupAlwaysController(TGController):
 
+class LookupAlwaysController(TGController):
 
     @expose()
     def _lookup(self, a, *args):
         return LookupAlwaysHelper(a), args
 
+
 class CustomDispatchingSubController(TGController):
 
     @expose()
@@ -82,137 +84,180 @@ class CustomDispatchingSubController(TGController):
         state.add_method(self.always, remainder)
         return state
 
+
 class OptionalArgumentRestController(RestController):
+
     @expose()
     def get_one(self, optional=None):
         return "SUBREST GET ONE"
+
     @expose()
     def put(self, optional=None):
-        return "SUBREST PUT"
+        return "subrest put"
+
     @expose()
     def post(self, optional=None):
-        return "SUBREST POST"
+        return "subrest post"
+
     @expose()
     def edit(self, optional=None):
-        return "SUBREST EDIT"
+        return "subrest edit"
+
     @expose()
     def new(self, optional=None):
-        return "SUBREST NEW"
+        return "subrest new"
+
     @expose()
     def get_delete(self, optional=None):
-        return "SUBREST GET DELETE"
+        return "subrest get delete"
+
     @expose()
     def post_delete(self, optional=None):
-        return "SUBREST POST DELETE"
+        return "subrest post delete"
+
 
 class RequiredArgumentRestController(RestController):
+
     @expose()
     def get_one(self, something):
-        return "SUBREST GET ONE"
+        return "subrest get one"
+
     @expose()
     def put(self, something):
-        return "SUBREST PUT"
+        return "subrest put"
+
     @expose()
     def post(self, something):
-        return "SUBREST POST"
+        return "subrest post"
+
     @expose()
     def edit(self, something):
-        return "SUBREST EDIT"
+        return "subrest edit"
+
     @expose()
     def new(self):
-        return "SUBREST NEW"
+        return "subrest new"
+
     @expose()
     def get_delete(self, something):
-        return "SUBREST GET DELETE"
+        return "subrest get delete"
+
     @expose()
     def post_delete(self, something):
-        return "SUBREST POST DELETE"
+        return "subrest post delete"
+
 
 class VariableSubRestController(RestController):
+
     @expose()
     def get_one(self, *args):
-        return "SUBREST GET ONE"
+        return "subrest get one"
+
     @expose()
     def put(self, *args):
-        return "SUBREST PUT"
+        return "subrest put"
+
     @expose()
     def edit(self, *args):
-        return "SUBREST EDIT"
+        return "subrest edit"
+
     @expose()
     def new(self, *args):
-        return "SUBREST NEW"
+        return "subrest new"
+
     @expose()
     def get_delete(self, *args):
-        return "SUBREST GET DELETE"
+        return "subrest get delete"
+
     @expose()
     def post_delete(self, *args):
-        return "SUBREST POST DELETE"
+        return "subrest post delete"
+
 
 class SubRestController(RestController):
+
     @expose()
     def get_all(self):
-        return "SUBREST GET ALL"
+        return "subrest get all"
+
     @expose()
-    def get_one(self, id):
-        return "SUBREST GET ONE"
+    def get_one(self, nr):
+        return "subrest get one %s" % nr
+
     @expose()
     def new(self):
-        return "SUBREST NEW"
+        return "subrest new"
+
     @expose()
-    def edit(self, id):
-        return "SUBREST EDIT"
+    def edit(self, nr):
+        return "subrest edit %s" % nr
+
     @expose()
     def post(self):
-        return "SUBREST POST"
+        return "subrest post"
+
     @expose()
-    def put(self, id):
-        return "SUBREST PUT"
+    def put(self, nr):
+        return "subrest put %s" % nr
+
     @expose()
     def fxn(self):
-        return "SUBREST FXN"
+        return "subrest fxn"
+
     @expose()
-    def get_delete(self, id):
-        return "SUBREST GET DELETE"
+    def get_delete(self, nr):
+        return "subrest get delete %s" % nr
+
     @expose()
-    def post_delete(self, id):
-        return "SUBREST POST DELETE"
+    def post_delete(self, nr):
+        return "subrest post delete %s" % nr
 
 
 class VariableRestController(RestController):
+
     subrest = SubRestController()
     vsubrest = VariableSubRestController()
 
     @expose()
     def get_all(self):
-        return "REST GET ALL"
+        return "rest get all"
+
     @expose()
     def get_one(self, *args):
-        return "REST GET ONE"
+        return "rest get onE"
+
     @expose()
     def get_delete(self, *args):
-        return "REST GET DELETE"
+        return "rest get delete"
+
     @expose()
     def post_delete(self, *args):
-        return "REST POST DELETE"
+        return "rest post delete"
+
 
 class ExtraRestController(RestController):
+
     @expose()
     def get_all(self):
-        return "REST GET ALL"
+        return "rest get all"
+
     @expose()
-    def get_one(self, id):
-        return "REST GET ONE"
+    def get_one(self, nr):
+        return "rest get one %s" % nr
+
     @expose()
-    def get_delete(self, id):
-        return "REST GET DELETE"
+    def get_delete(self, nr):
+        return "rest get delete %s" % nr
+
     @expose()
-    def post_delete(self, id):
-        return "REST POST DELETE"
+    def post_delete(self, nr):
+        return "rest post delete %s" % nr
 
     class sub(TGController):
+
         @expose()
         def index(self):
-            return "REST SUB INDEX"
+            return "rest sub index"
 
     subrest = SubRestController()
     optsubrest = OptionalArgumentRestController()
@@ -228,29 +273,35 @@ class ExtraRestController(RestController):
     def get_archive(self):
         return 'got to get archive'
 
+
 class BasicRestController(RestController):
 
     @expose()
     def get(self):
-        return "REST GET"
+        return "rest get"
+
     @expose()
     def post(self):
-        return "REST POST"
+        return "rest post"
+
     @expose()
     def put(self):
-        return "REST PUT"
+        return "rest put"
+
     @expose()
     def delete(self):
-        return "REST DELETE"
+        return "rest delete"
+
     @expose()
     def new(self):
-        return "REST NEW"
+        return "rest new"
     @expose()
     def edit(self, *args, **kw):
-        return "REST EDIT"
+        return "rest edit"
+
     @expose()
     def other(self):
-        return "REST OTHER"
+        return "rest other"
 
     _custom_actions = ['archive']
 
@@ -258,16 +309,20 @@ class BasicRestController(RestController):
     def archive(self):
         return 'got to archive'
 
+
 class EmptyRestController(RestController):
     pass
 
+
 class SubController(TGController):
+
     rest = BasicRestController()
 
     @expose()
     def sub_method(self, arg):
         return 'sub %s'%arg
 
+
 class BasicTGController(TGController):
 
     sub = SubController()
@@ -285,43 +340,49 @@ class BasicTGController(TGController):
         return 'hello world'
 
     @expose()
-    def default(self, *remainder):
-        return "Main Default Page called for url /%s"%list(remainder)
+    def _default(self, *remainder):
+        return "Main default page called for url /%s" % list(remainder)
 
     @expose()
     def hello(self, name, silly=None):
-        return "Hello " + name
+        return "Hello %s" % name
+
 
 class BasicTGControllerNoDefault(TGController):
+
     @expose()
     def index(self, **kwargs):
         return 'hello world'
 
+
 class TestTGControllerRoot(TestWSGIController):
+
     def __init__(self, *args, **kargs):
         TestWSGIController.__init__(self, *args, **kargs)
         self.app = make_app(BasicTGControllerNoDefault)
 
     def test_root_default_dispatch(self):
-        resp = self.app.get('/i/am/not/a/sub/controller', status=404)
+        self.app.get('/i/am/not/a/sub/controller', status=404)
+
 
 class TestTGController(TestWSGIController):
+
     def __init__(self, *args, **kargs):
         TestWSGIController.__init__(self, *args, **kargs)
         self.app = make_app(BasicTGController)
 
     def test_lookup(self):
-        r = self.app.get('/lookup/EYE')
-        msg = 'EYE'
+        r = self.app.get('/lookup/eye')
+        msg = 'eye'
         assert msg in r, r
 
     def test_deprecated_lookup(self):
-        r = self.app.get('/deprecated_lookup/EYE')
-        msg = 'EYE'
+        r = self.app.get('/deprecated_lookup/eye')
+        msg = 'eye'
         assert msg in r, r
 
     def test_lookup_with_dispatch(self):
-        r = self.app.get('/lookup_dispatch/EYE')
+        r = self.app.get('/lookup_dispatch/eye')
         msg = 'always'
         assert msg in r, r
 
@@ -365,7 +426,7 @@ class TestRestController(TestWSGIController):
 
     def test_post(self):
         r = self.app.post('/rest/')
-        assert 'REST POST' in r, r
+        assert 'rest post' in r, r
 
     def _test_non_resty(self):
         r = self.app.post('/rest/non_resty_thing')
@@ -393,75 +454,75 @@ class TestRestController(TestWSGIController):
 
     def test_get(self):
         r = self.app.get('/rest/')
-        assert 'REST GET' in r, r
+        assert 'rest get' in r, r
 
     def test_put(self):
         r = self.app.put('/rest/')
-        assert 'REST PUT' in r, r
+        assert 'rest put' in r, r
 
     def test_put_post(self):
         r = self.app.post('/rest?_method=PUT')
-        assert 'REST PUT' in r, r
+        assert 'rest put' in r, r
+
+    def test_put_post_params(self):
+        r = self.app.post('/rest', params={'_method':'PUT'})
+        assert 'rest put' in r, r
 
     def test_put_get(self):
-        r = self.app.get('/rest?_method=PUT', status=405)
-
-    def test_put_post(self):
-        r = self.app.post('/rest', params={'_method':'PUT'})
-        assert 'REST PUT' in r, r
+        self.app.get('/rest?_method=PUT', status=405)
 
     def test_get_delete_bad(self):
-        r = self.app.get('/rest?_method=DELETE', status=405)
+        self.app.get('/rest?_method=DELETE', status=405)
 
     def test_delete(self):
         r = self.app.delete('/rest/')
-        assert 'REST DELETE' in r, r
+        assert 'rest delete' in r, r
 
     def test_post_delete(self):
         r = self.app.post('/rest/', params={'_method':'DELETE'})
-        assert 'REST DELETE' in r, r
+        assert 'rest delete' in r, r
 
     def test_get_all(self):
         r = self.app.get('/rest2/')
-        assert 'REST GET ALL' in r, r
+        assert 'rest get all' in r, r
 
     def test_get_one(self):
         r = self.app.get('/rest2/1')
-        assert 'REST GET ONE' in r, r
+        assert 'rest get one 1' in r, r
 
     def test_get_delete(self):
         r = self.app.get('/rest2/1/delete')
-        assert 'REST GET DELETE' in r, r
+        assert 'rest get delete' in r, r
 
-    def test_post_delete(self):
+    def test_post_delete_params(self):
         r = self.app.post('/rest2/1', params={'_method':'DELETE'})
-        assert 'REST POST DELETE' in r, r
+        assert 'rest post delete' in r, r
 
     def test_post_delete_var(self):
         r = self.app.post('/rest3/a/b/c', params={'_method':'DELETE'})
-        assert 'REST POST DELETE' in r, r
+        assert 'rest post delete' in r, r
 
     def test_get_delete_var(self):
         r = self.app.get('/rest3/a/b/c/delete')
-        assert 'REST GET DELETE' in r, r
+        assert 'rest get delete' in r, r
 
     def test_get_method(self):
         r = self.app.get('/rest/other')
-        assert 'REST OTHER' in r, r
+        assert 'rest other' in r, r
 
     @no_warn
     def test_get_sub_controller(self):
         r = self.app.get('/rest2/sub')
-        assert 'REST SUB INDEX' in r, r
+        assert 'rest sub index' in r, r
 
     @no_warn
     def test_put_sub_controller(self):
         r = self.app.put('/rest2/sub')
-        assert 'REST SUB INDEX' in r, r
+        assert 'rest sub index' in r, r
 
     def test_post_sub_controller(self):
         r = self.app.post('/rest2/sub')
-        assert 'REST SUB INDEX' in r, r
+        assert 'rest sub index' in r, r
 
     def test_post_miss(self):
         r = self.app.post('/rest2/something')
@@ -498,205 +559,196 @@ class TestRestController(TestWSGIController):
 
     def test_post_method(self):
         r = self.app.post('/rest/other')
-        assert 'REST OTHER' in r, r
+        assert 'rest other' in r, r
 
     def test_new_method(self):
         r = self.app.post('/rest/new')
-        assert 'REST NEW' in r, r
+        assert 'rest new' in r, r
 
     def test_edit_method(self):
         r = self.app.get('/rest/1/edit')
-        assert 'REST EDIT' in r, r
+        assert 'rest edit' in r, r
 
     def test_delete_method(self):
-        r = self.app.delete('/rest/other', status=405)
+        self.app.delete('/rest/other', status=405)
 
     def test_sub_with_rest_delete(self):
         r = self.app.delete('/sub/rest/')
-        assert 'REST DELETE' in r, r 
+        assert 'rest delete' in r, r
 
     def test_put_method(self):
         r = self.app.put('/rest/other')
-        assert 'REST OTHER' in r, r
+        assert 'rest other' in r, r
 
     def test_sub_get_all_method(self):
         r = self.app.get('/rest2/1/subrest')
-        assert 'SUBREST GET ALL' in r, r
+        assert 'subrest get all' in r, r
 
     def test_var_sub_get_all_method(self):
         r = self.app.get('/rest3/1/3/3/subrest')
-        assert 'SUBREST GET ALL' in r, r
+        assert 'subrest get all' in r, r
         r = self.app.get('/rest3/1/3/subrest')
-        assert 'SUBREST GET ALL' in r, r
+        assert 'subrest get all' in r, r
         r = self.app.get('/rest3/subrest')
-        assert 'SUBREST GET ALL' in r, r
+        assert 'subrest get all' in r, r
 
     def test_var_sub_get_one_method(self):
         r = self.app.get('/rest3/1/3/3/subrest/1')
-        assert 'SUBREST GET ONE' in r, r
+        assert 'subrest get one' in r, r
         r = self.app.get('/rest3/1/3/subrest/1')
-        assert 'SUBREST GET ONE' in r, r
+        assert 'subrest get one' in r, r
         r = self.app.get('/rest3/subrest/1')
-        assert 'SUBREST GET ONE' in r, r
+        assert 'subrest get one' in r, r
 
     def test_var_sub_edit_method(self):
         r = self.app.get('/rest3/1/3/3/subrest/1/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest edit' in r, r
         r = self.app.get('/rest3/1/3/subrest/1/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest edit' in r, r
         r = self.app.get('/rest3/subrest/1/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest edit' in r, r
 
     def test_var_sub_edit_var_method(self):
         r = self.app.get('/rest3/1/3/3/vsubrest/1/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest edit' in r, r
         r = self.app.get('/rest3/1/3/vsubrest/1/a/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest edit' in r, r
         r = self.app.get('/rest3/vsubrest/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest edit' in r, r
 
     def test_var_sub_delete_method(self):
         r = self.app.get('/rest3/1/3/3/subrest/1/delete')
-        assert 'SUBREST GET DELETE' in r, r
+        assert 'subrest get delete' in r, r
         r = self.app.get('/rest3/1/3/subrest/1/delete')
-        assert 'SUBREST GET DELETE' in r, r
+        assert 'subrest get delete' in r, r
         r = self.app.get('/rest3/subrest/1/delete')
-        assert 'SUBREST GET DELETE' in r, r
-
-    def test_var_sub_edit_var_method(self):
-        r = self.app.get('/rest3/1/3/3/vsubrest/1/edit')
-        assert 'SUBREST EDIT' in r, r
-        r = self.app.get('/rest3/1/3/vsubrest/1/a/edit')
-        assert 'SUBREST EDIT' in r, r
-        r = self.app.get('/rest3/vsubrest/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest get delete' in r, r
 
     def test_var_sub_new_method(self):
         r = self.app.get('/rest3/1/3/3/subrest/new')
-        assert 'SUBREST NEW' in r, r
+        assert 'subrest new' in r, r
         r = self.app.get('/rest3/1/3/subrest/new')
-        assert 'SUBREST NEW' in r, r
+        assert 'subrest new' in r, r
         r = self.app.get('/rest3/subrest/new')
-        assert 'SUBREST NEW' in r, r
+        assert 'subrest new' in r, r
 
     def test_var_sub_var_get_one_method(self):
         r = self.app.get('/rest3/1/3/3/vsubrest/1')
-        assert 'SUBREST GET ONE' in r, r
+        assert 'subrest get one' in r, r
         r = self.app.get('/rest3/1/3/vsubrest/1/a')
-        assert 'SUBREST GET ONE' in r, r
+        assert 'subrest get one' in r, r
         r = self.app.get('/rest3/vsubrest/')
-        assert 'SUBREST GET ONE' in r, r
+        assert 'subrest get one' in r, r
 
     def test_var_sub_var_put_method(self):
         r = self.app.put('/rest3/1/3/3/vsubrest/1')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
         r = self.app.put('/rest3/1/3/vsubrest/1/asdf')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
         r = self.app.put('/rest3/vsubrest/')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
 
     def test_var_sub_post_method(self):
         r = self.app.post('/rest3/1/3/3/subrest/')
-        assert 'SUBREST POST' in r, r
+        assert 'subrest post' in r, r
         r = self.app.post('/rest3/1/3/subrest/')
-        assert 'SUBREST POST' in r, r
+        assert 'subrest post' in r, r
         r = self.app.post('/rest3/subrest/')
-        assert 'SUBREST POST' in r, r
+        assert 'subrest post' in r, r
+
+    def test_var_sub_post_delete_method(self):
+        r = self.app.delete('/rest3/1/3/3/subrest/1')
+        assert 'subrest post delete' in r, r
+        r = self.app.delete('/rest3/1/3/subrest/1')
+        assert 'subrest post delete' in r, r
 
     def test_var_sub_put_method(self):
         r = self.app.put('/rest3/1/3/3/subrest/1')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
         r = self.app.put('/rest3/1/3/subrest/1')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
         r = self.app.put('/rest3/subrest/1')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
 
     def test_var_sub_put_hack_method(self):
         r = self.app.post('/rest3/1/3/3/subrest/1?_method=PUT')
-        assert 'SUBREST PUT' in r, r
-        r = self.app.post('/rest3/1/3/subrest/1?_method=PUT')
-        assert 'SUBREST PUT' in r, r
-        r = self.app.post('/rest3/subrest/1?_method=PUT')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
+        r = self.app.post('/rest3/1/3/subrest/1?_method=put')
+        assert 'subrest put' in r, r
+        r = self.app.post('/rest3/subrest/1?_method=put')
+        assert 'subrest put' in r, r
 
     def test_var_sub_var_delete_method(self):
         r = self.app.delete('/rest3/1/3/3/vsubrest/1')
-        assert 'SUBREST POST DELETE' in r, r
+        assert 'subrest post delete' in r, r
         r = self.app.delete('/rest3/1/3/vsubrest/1')
-        assert 'SUBREST POST DELETE' in r, r
+        assert 'subrest post delete' in r, r
         r = self.app.delete('/rest3/vsubrest/')
-        assert 'SUBREST POST DELETE' in r, r
+        assert 'subrest post delete' in r, r
 
     def test_var_sub_delete_var_hack_method(self):
         r = self.app.post('/rest3/1/3/3/vsubrest/1?_method=DELETE')
-        assert 'SUBREST POST DELETE' in r, r
-        r = self.app.post('/rest3/1/3/vsubrest/1?_method=DELETE')
-        assert 'SUBREST POST DELETE' in r, r
-        r = self.app.post('/rest3/vsubrest?_method=DELETE')
-        assert 'SUBREST POST DELETE' in r, r
+        assert 'subrest post delete' in r, r
+        r = self.app.post('/rest3/1/3/vsubrest/1?_method=delete')
+        assert 'subrest post delete' in r, r
+        r = self.app.post('/rest3/vsubrest?_method=delete')
+        assert 'subrest post delete' in r, r
 
     def test_var_sub_var_put_hack_method(self):
         r = self.app.post('/rest3/1/3/3/vsubrest/1?_method=PUT')
-        assert 'SUBREST PUT' in r, r
-        r = self.app.post('/rest3/1/3/vsubrest/1/a?_method=PUT')
-        assert 'SUBREST PUT' in r, r
-        r = self.app.post('/rest3/vsubrest/?_method=PUT')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
+        r = self.app.post('/rest3/1/3/vsubrest/1/a?_method=put')
+        assert 'subrest put' in r, r
+        r = self.app.post('/rest3/vsubrest/?_method=put')
+        assert 'subrest put' in r, r
 
     def test_var_sub_delete_hack_method(self):
         r = self.app.post('/rest3/1/3/3/subrest/1?_method=DELETE')
-        assert 'SUBREST POST DELETE' in r, r
-        r = self.app.post('/rest3/1/3/subrest/1?_method=DELETE')
-        assert 'SUBREST POST DELETE' in r, r
-        r = self.app.post('/rest3/subrest/1?_method=DELETE')
-        assert 'SUBREST POST DELETE' in r, r
-
-    def test_var_sub_delete_method(self):
-        r = self.app.delete('/rest3/1/3/3/subrest/1')
-        assert 'SUBREST POST DELETE' in r, r
-        r = self.app.delete('/rest3/1/3/subrest/1')
-        assert 'SUBREST POST DELETE' in r, r
+        assert 'subrest post delete' in r, r
+        r = self.app.post('/rest3/1/3/subrest/1?_method=delete')
+        assert 'subrest post delete' in r, r
+        r = self.app.post('/rest3/subrest/1?_method=delete')
+        assert 'subrest post delete' in r, r
 
     def test_sub_new(self):
         r = self.app.get('/rest2/1/subrest/new')
-        assert 'SUBREST NEW' in r, r
+        assert 'subrest new' in r, r
 
     def test_sub_edit(self):
         r = self.app.get('/rest2/1/subrest/1/edit')
-        assert 'SUBREST EDIT' in r, r
+        assert 'subrest edit' in r, r
 
     def test_sub_post(self):
         r = self.app.post('/rest2/1/subrest/')
-        assert 'SUBREST POST' in r, r
+        assert 'subrest post' in r, r
 
     def test_sub_put(self):
         r = self.app.put('/rest2/1/subrest/2')
-        assert 'SUBREST PUT' in r, r
-
-    def test_sub_post(self):
-        r = self.app.post('/rest2/1/subrest/')
-        assert 'SUBREST POST' in r, r
+        assert 'subrest put' in r, r
 
     def test_sub_post_opt(self):
         r = self.app.post('/rest2/1/optsubrest/1')
-        assert 'SUBREST POST' in r, r
+        assert 'subrest post' in r, r
+
     def test_sub_put_opt(self):
         r = self.app.put('/rest2/1/optsubrest/1')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
+
     def test_sub_put_opt_hack(self):
         r = self.app.post('/rest2/1/optsubrest/1?_method=PUT')
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
+
     def test_sub_delete_opt_hack(self):
         r = self.app.post('/rest2/1/optsubrest/1?_method=DELETE')
-        assert 'SUBREST ' in r, r
+        assert 'subrest ' in r, r
 
     def test_put_post_req(self):
         r = self.app.post('/rest2/reqsubrest', params={'something':'required'})
-        assert 'SUBREST POST' in r, r
+        assert 'subrest post' in r, r
 
     def test_sub_put_req(self):
         r = self.app.post('/rest2/reqsubrest', params={'_method':'PUT', 'something':'required'})
-        assert 'SUBREST PUT' in r, r
+        assert 'subrest put' in r, r
 
     def test_sub_post_req_bad(self):
         r = self.app.post('/rest2/reqsubrest',)
@@ -704,20 +756,20 @@ class TestRestController(TestWSGIController):
 
     def test_sub_delete_hack(self):
         r = self.app.post('/rest2/1/subrest/2?_method=DELETE')
-        assert 'SUBREST POST DELETE' in r, r
+        assert 'subrest post delete' in r, r
 
     def test_sub_get_delete(self):
         r = self.app.get('/rest2/1/subrest/2/delete')
-        assert 'SUBREST GET DELETE' in r, r
+        assert 'subrest get delete' in r, r
 
     def test_sub_post_delete(self):
         r = self.app.delete('/rest2/1/subrest/2')
-        assert 'SUBREST POST DELETE' in r, r
+        assert 'subrest post delete' in r, r
 
     def test_sub_get_fxn(self):
         r = self.app.get('/rest2/1/subrest/fxn')
-        assert 'SUBREST FXN' in r, r
+        assert 'subrest fxn' in r, r
 
     def test_sub_post_fxn(self):
         r = self.app.post('/rest2/1/subrest/fxn')
-        assert 'SUBREST FXN' in r, r
+        assert 'subrest fxn' in r, r
