@@ -1,6 +1,6 @@
 """Main Controller"""
 
-from tg import expose, redirect, config, validate, override_template
+from tg import expose, redirect, config, validate, override_template, response
 from tg.decorators import paginate, use_custom_format, with_trailing_slash
 from tg.controllers import TGController
 from tw.forms import TableForm, TextField, CalendarDatePicker, SingleSelectField, TextArea
@@ -56,10 +56,22 @@ class RootController(TGController):
     def index(self):
         return {}
 
+    @expose('genshi:index_autodoctype.html')
+    def autodoctype(self):
+        return {}
+
+    @expose('genshi:index_autodoctype.html', content_type='application/xhtml+xml')
+    def autodoctype_xhtml_strict(self):
+        return {}
+
     @expose('genshi:genshi_form.html')
     def form(self):
         return dict(form=base_movie_form)
 
+    @expose('genshi:genshi_foreign.html')
+    def foreign(self):
+        return {}
+
     @expose('json')
     @validate(form=base_movie_form)
     def process_form_errors(self, **kwargs):
@@ -72,6 +84,12 @@ class RootController(TGController):
     def paginated(self, n):
         return dict(testdata=range(int(n)))
 
+    @expose('genshi:genshi_paginated.html')
+    @paginate('testdata')
+    def paginate_with_params(self, n):
+        url_params = dict(param1='hi', param2='man')
+        return dict(testdata=range(int(n)), url_params=url_params)
+
     @expose('genshi:genshi_paginated.html')
     @paginate('testdata')
     @validate(dict(n=validators.Int()))
@@ -104,6 +122,17 @@ class RootController(TGController):
     def jinja_inherits(self):
         return {}
 
+    @expose('jinja:jinja_extensions.html')
+    def jinja_extensions(self):
+        test_autoescape_on = "<b>Test Autoescape On</b>"
+        test_autoescape_off = "<b>Autoescape Off</b>"
+        return dict(test_autoescape_off=test_autoescape_off,
+                test_autoescape_on=test_autoescape_on)
+
+    @expose('jinja:jinja_filters.html')
+    def jinja_filters(self):
+        return {}
+
     @expose('chameleon_genshi:index.html')
     def chameleon_genshi_index(self):
         return {}
@@ -183,3 +212,11 @@ class RootController(TGController):
         else:
             return "alert('Not overridden')"
 
+    @expose('mako:mako_custom_format.mak', content_type='text/xml')
+    @expose('genshi:genshi_custom_format.html', content_type='text/html')
+    def template_override_multiple_content_type(self, override=False):
+        if override:
+            override_template(self.template_override_multiple_content_type, "mako:mako_noop.mak")
+        return dict(format='something', status="ok")
+
+
