@@ -1,31 +1,36 @@
 # -*- coding: utf-8 -*-
 
-import tg, pylons
-from tg.controllers import TGController, CUSTOM_CONTENT_TYPE, \
-                           WSGIAppController, RestController
-from tg.decorators import expose, validate, override_template
-from tg.util import no_warn
-from routes import Mapper
-from routes.middleware import RoutesMiddleware
-from formencode import validators
-from webob import Response, Request
-from nose.tools import raises
-
-from tests.base import TestWSGIController, make_app, setup_session_dir, \
-                          teardown_session_dir
-
 from wsgiref.simple_server import demo_app
 from wsgiref.validate import validator
+
+from formencode import validators
+
+from webob import Response, Request
+
 from pylons.controllers.xmlrpc import XMLRPCController
 
-from pylons import config
+import tg
+from tg import config, tmpl_context
+from tg.controllers import (
+    TGController, CUSTOM_CONTENT_TYPE, WSGIAppController)
+from tg.decorators import expose, validate
+from tg.util import no_warn
+
+from tests.base import (
+    TestWSGIController, make_app, setup_session_dir, teardown_session_dir)
+
+
 config['renderers'] = ['genshi', 'mako', 'json']
 
+
 def setup():
     setup_session_dir()
+
+
 def teardown():
     teardown_session_dir()
 
+
 def wsgi_app(environ, start_response):
     req = Request(environ)
     if req.method == 'POST':
@@ -34,45 +39,53 @@ def wsgi_app(environ, start_response):
         resp = Response("Hello from %s/%s"%(req.script_name, req.path_info))
     return resp(environ, start_response)
 
+
 class XMLRpcTestController(XMLRPCController):
+
     def textvalue(self):
         return 'hi from xmlrpc'
+
     textvalue.signature = [ ['string'] ]
 
+
 class BeforeController(TGController):
 
     def _before(self, *args, **kw):
-        pylons.tmpl_context.var = '__my_before__'
-        
+        tmpl_context.var = '__my_before__'
+
     def _after(self, *args, **kw):
         global_craziness = '__my_after__'
 
     @expose()
     def index(self):
-        assert pylons.tmpl_context.var
-        return pylons.tmpl_context.var
+        assert tmpl_context.var
+        return tmpl_context.var
+
 
 class NewBeforeController(TGController):
+
     def _before(self, *args, **kw):
-        pylons.tmpl_context.var = '__my_before__'
-        pylons.tmpl_context.args = args
-        pylons.tmpl_context.params = kw
+        tmpl_context.var = '__my_before__'
+        tmpl_context.args = args
+        tmpl_context.params = kw
 
     def _after(self, *args, **kw):
         global_craziness = '__my_after__'
 
     @expose()
     def index(self):
-        assert pylons.tmpl_context.var
-        return pylons.tmpl_context.var
+        assert tmpl_context.var
+        return tmpl_context.var
 
     @expose()
     def with_args(self, *args, **kw):
-        assert pylons.tmpl_context.args
-        assert pylons.tmpl_context.params
-        return pylons.tmpl_context.var+pylons.tmpl_context.params['environ']['webob._parsed_query_vars'][0]['x']
+        assert tmpl_context.args
+        assert tmpl_context.params
+        return tmpl_context.var + tmpl_context.params['environ']['webob._parsed_query_vars'][0]['x']
+
 
 class SubController(object):
+
     mounted_app = WSGIAppController(wsgi_app)
 
     before = BeforeController()
@@ -91,8 +104,8 @@ class SubController(object):
         return 'sub index'
 
     @expose()
-    def default(self, *args):
-        return ("recieved the following args (from the url): %s" %str([str(a) for a in args]))
+    def _default(self, *args):
+        return "received the following args (from the url): %s" % list(args)
 
     @expose()
     def redirect_me(self, target, **kw):
@@ -104,14 +117,17 @@ class SubController(object):
 
     @expose()
     def hello(self, name):
-        return "Why HELLO! " + name
+        return "Why hello, %s!" % name
+
 
 class SubController3(object):
     @expose()
     def get_all(self):
         return 'Sub 3'
 
+
 class SubController2(object):
+
     @expose()
     def index(self):
         tg.redirect('list')
@@ -120,6 +136,7 @@ class SubController2(object):
     def list(self, **kw):
         return "hello list"
 
+
 class LookupHelper:
 
     def __init__(self, var):
@@ -129,6 +146,7 @@ class LookupHelper:
     def index(self):
         return self.var
 
+
 class LookupHelperWithArgs:
 
     @expose()
@@ -139,36 +157,39 @@ class LookupHelperWithArgs:
     def post_with_mixed_args(self, arg1, arg2, **kw):
         return "%s%s" % (arg1, arg2)
 
+
 class LookupControllerWithArgs(TGController):
 
     @expose()
     def _lookup(self, *args):
-        l = LookupHelperWithArgs()
-#        print 'inside _lookup', l, args
-        return l, args
+        helper = LookupHelperWithArgs()
+        return helper, args
+
 
 class LookupController(TGController):
 
     @expose()
     def _lookup(self, a, *args):
         return LookupHelper(a), args
-    
+
+
 class LookupWithEmbeddedLookupController(TGController):
-    
+
     @expose()
     def _lookup(self, *args):
         return LookupControllerWithArgs(), args
 
+
 class LookupHelperWithIndex:
 
     @expose()
     def index(self):
         return "helper index"
-    
+
     @expose()
     def method(self):
         return "helper method"
-    
+
 
 class LookupControllerWithIndexHelper(TGController):
 
@@ -180,16 +201,18 @@ class LookupControllerWithIndexHelper(TGController):
     def index(self):
         return "second controller with index"
 
+
 class LookupWithEmbeddedLookupWithHelperWithIndex(TGController):
 
     @expose()
     def _lookup(self, a, *args):
         return LookupControllerWithIndexHelper(), args
-    
+
     @expose()
     def index(self):
         return "first controller with index"
 
+
 class LookupControllerWithSubcontroller(TGController):
 
     class SubController(object): pass
@@ -198,37 +221,57 @@ class LookupControllerWithSubcontroller(TGController):
     def _lookup(self, a, *args):
         return self.SubController(), args
 
+
 class RemoteErrorHandler(TGController):
     @expose()
     def errors_here(self, *args, **kw):
-        return "REMOTE ERROR HANDLER"
+        return "remote error handler"
+
+
+class NotFoundController(TGController):
+    pass
 
-class NotFoundController(TGController):pass
 
 class DefaultWithArgsController(TGController):
+
+    @expose()
+    def _default(self, a, b=None, **kw):
+        return "default with args %s %s" % (a, b)
+
+
+class DeprecatedDefaultWithArgsController(TGController):
+
     @expose()
     def default(self, a, b=None, **kw):
-        return "DEFAULT WITH ARGS %s %s"%(a, b)
+        return "deprecated default with args %s %s" % (a, b)
+
 
 class DefaultWithArgsAndValidatorsController(TGController):
+
     @expose()
     def failure(self, *args, **kw):
-        return "FAILURE"
+        return "failure"
 
     @expose()
-    @validate({'a': validators.Int(),
-              'b': validators.StringBool()}, error_handler=failure)
-    def default(self, a, b=None, **kw):
-        return "DEFAULT WITH ARGS AND VALIDATORS %s %s"%(a, b)
+    @validate(dict(a=validators.Int(), b=validators.StringBool()),
+        error_handler=failure)
+    def _default(self, a, b=None, **kw):
+        return "default with args and validators %s %s"%(a, b)
+
 
 class SubController4:
+
     default_with_args = DefaultWithArgsController()
+    deprecated_default_with_args = DeprecatedDefaultWithArgsController()
+
 
 class SubController5:
+
     default_with_args = DefaultWithArgsAndValidatorsController()
 
+
 class HelperWithSpecificArgs(TGController):
-    
+
     @expose()
     def index(self, **kw):
         return str(kw)
@@ -236,7 +279,8 @@ class HelperWithSpecificArgs(TGController):
     @expose()
     def method(self, arg1, arg2, **kw):
         return str((arg1, arg2, kw))
-    
+
+
 class SelfCallingLookupController(TGController):
 
     @expose()
@@ -246,12 +290,14 @@ class SelfCallingLookupController(TGController):
         a = [a]
         a.extend(args)
         return HelperWithSpecificArgs(), a
-    
+
     @expose()
     def index(self, *args, **kw):
         return str((args, kw))
 
+
 class BasicTGController(TGController):
+
     mounted_app = WSGIAppController(wsgi_app)
     xml_rpc = WSGIAppController(XMLRpcTestController())
 
@@ -271,8 +317,8 @@ class BasicTGController(TGController):
         return 'hello world'
 
     @expose()
-    def default(self, *remainder):
-        return "Main Default Page called for url /%s"%list(remainder)
+    def _default(self, *remainder):
+        return "Main default page called for url /%s" % list(remainder)
 
     @expose()
     def feed(self, feed=None):
@@ -282,14 +328,13 @@ class BasicTGController(TGController):
     sub2 = SubController2()
     sub4 = SubController4()
     sub5 = SubController5()
-    
+
     embedded_lookup = LookupWithEmbeddedLookupController()
     embedded_lookup_with_index = LookupWithEmbeddedLookupWithHelperWithIndex()
 
     @expose()
-    def test_args(self, id, one=None, two=2, three=3):
-        r = dict(id=id, one=str(one), two=str(two), three=str(three))
-        return str(r)
+    def test_args(self, name, one=None, two=2, three=3):
+        return "name=%s, one=%s, two=%s, three=%s" % (name, one, two, three)
 
     @expose()
     def redirect_me(self, target, **kw):
@@ -300,10 +345,8 @@ class BasicTGController(TGController):
         return "Hello " + name
 
     @expose()
-    def optional_and_req_args(self, id, one=None, two=2, three=3):
-        r = dict(id=id, one=str(one), two=str(two), three=str(three))
-
-        return str(r)
+    def optional_and_req_args(self, name, one=None, two=2, three=3):
+        return "name=%s, one=%s, two=%s, three=%s" % (name, one, two, three)
 
     @expose()
     def ticket2412(self, arg1):
@@ -311,12 +354,12 @@ class BasicTGController(TGController):
 
     @expose()
     def redirect_cookie(self, name):
-        pylons.response.set_cookie('name', name)
+        tg.response.set_cookie('name', name)
         tg.redirect('/hello_cookie')
 
     @expose()
     def hello_cookie(self):
-        return "Hello " + pylons.request.cookies['name']
+        return "Hello " + tg.request.cookies['name']
 
     @expose()
     def flash_redirect(self):
@@ -342,13 +385,13 @@ class BasicTGController(TGController):
         return tg.get_flash()
 
     @expose('json')
-    @validate(validators={"some_int": validators.Int()})
+    @validate(validators=dict(some_int=validators.Int()))
     def validated_int(self, some_int):
         assert isinstance(some_int, int)
         return dict(response=some_int)
 
     @expose('json')
-    @validate(validators={"a":validators.Int()})
+    @validate(validators=dict(a=validators.Int()))
     def validated_and_unvalidated(self, a, b):
         assert isinstance(a, int)
         assert isinstance(b, unicode)
@@ -356,17 +399,19 @@ class BasicTGController(TGController):
 
     @expose()
     def error_handler(self, **kw):
-        return 'VALIDATION ERROR HANDLER'
+        return 'validation error handler'
 
     @expose('json')
-    @validate(validators={"a":validators.Int()}, error_handler=error_handler)
+    @validate(validators=dict(a=validators.Int()),
+        error_handler=error_handler)
     def validated_with_error_handler(self, a, b):
         assert isinstance(a, int)
         assert isinstance(b, unicode)
         return dict(int=a,str=b)
 
     @expose('json')
-    @validate(validators={"a":validators.Int()}, error_handler=error_controller.errors_here)
+    @validate(validators=dict(a=validators.Int()),
+        error_handler=error_controller.errors_here)
     def validated_with_remote_error_handler(self, a, b):
         assert isinstance(a, int)
         assert isinstance(b, unicode)
@@ -383,17 +428,17 @@ class BasicTGController(TGController):
 
     @expose()
     def custom_content_type_in_controller(self):
-        pylons.response.headers['content-type'] = 'image/png'
+        tg.response.headers['content-type'] = 'image/png'
         return 'PNG'
 
     @expose('json', content_type='application/json')
     def custom_content_type_in_controller_charset(self):
-        pylons.response.headers['content-type'] = 'application/json; charset=utf-8'
+        tg.response.headers['content-type'] = 'application/json; charset=utf-8'
         return dict(result='TXT')
 
     @expose(content_type=CUSTOM_CONTENT_TYPE)
     def custom_content_type_with_ugliness(self):
-        pylons.response.headers['content-type'] = 'image/png'
+        tg.response.headers['content-type'] = 'image/png'
         return 'PNG'
 
     @expose(content_type='image/png')
@@ -407,14 +452,16 @@ class BasicTGController(TGController):
 
     @expose()
     def custom_content_type_replace_header(self):
-        replace_header(pylons.response.headerlist, 'Content-Type', 'text/xml')
+        replace_header(tg.response.headerlist, 'Content-Type', 'text/xml')
         return "<?xml version='1.0'?>"
 
     @expose()
     def multi_value_kws(sekf, *args, **kw):
         assert kw['foo'] == ['1', '2'], kw
 
+
 class TestNotFoundController(TestWSGIController):
+
     def __init__(self, *args, **kargs):
         TestWSGIController.__init__(self, *args, **kargs)
         self.app = make_app(NotFoundController)
@@ -431,13 +478,15 @@ class TestNotFoundController(TestWSGIController):
         r = self.app.get('/права', status=404)
         assert '404 Not Found' in r, r
 
+
 class TestWSGIAppController(TestWSGIController):
+
     def __init__(self, *args, **kargs):
         TestWSGIController.__init__(self, *args, **kargs)
         class TestedWSGIAppController(WSGIAppController):
             def __init__(self):
                 def test_app(environ, start_response):
-                    if environ['CONTENT_LENGTH'] in (-1, '-1'):
+                    if environ.get('CONTENT_LENGTH', None) in (-1, '-1'):
                         del environ['CONTENT_LENGTH']
                     return validator(demo_app)(environ, start_response)
                 super(TestedWSGIAppController, self).__init__(test_app)
@@ -450,9 +499,10 @@ class TestWSGIAppController(TestWSGIController):
             raise AssertionError(str(e))
         assert 'some_url' in r
 
+
 class TestTGController(TestWSGIController):
+
     def setUp(self, *args, **kargs):
-        
         TestWSGIController.setUp(self, *args, **kargs)
         self.app = make_app(BasicTGController)
 
@@ -482,12 +532,12 @@ class TestTGController(TestWSGIController):
 
     def test_validated_with_error_handler(self):
         r = self.app.get('/validated_with_error_handler?a=asdf&b=123')
-        msg = 'VALIDATION ERROR HANDLER'
+        msg = 'validation error handler'
         assert msg in r, r
 
     def test_validated_with_remote_error_handler(self):
         r = self.app.get('/validated_with_remote_error_handler?a=asdf&b=123')
-        msg = 'REMOTE ERROR HANDLER'
+        msg = 'remote error handler'
         assert msg in r, r
 
     def test_unknown_template(self):
@@ -526,7 +576,7 @@ class TestTGController(TestWSGIController):
 
     def test_multi_value_kw(self):
         r = self.app.get('/multi_value_kws?foo=1&foo=2')
-    
+
     def test_before_controller(self):
         r = self.app.get('/sub/before')
         assert '__my_before__' in r, r
@@ -544,33 +594,51 @@ class TestTGController(TestWSGIController):
         r =self.app.get('/sub/äö')
         assert "\\xc3\\xa4\\xc3\\xb6" in r, r
 
-    def test_defalt_with_empty_second_arg(self):
+    def test_default_with_empty_second_arg(self):
         r =self.app.get('/sub4/default_with_args/a')
-        assert "DEFAULT WITH ARGS a None" in r.body, r
+        assert "default with args a None" in r.body, r
+        assert "deprecated" not in r.body
+        import warnings
+        warnings.filterwarnings('ignore', category=DeprecationWarning)
+        r = self.app.get('/sub4/deprecated_default_with_args/a')
+        warnings.resetwarnings()
+        assert "deprecated default with args a None" in r.body, r
 
-    def test_defalt_with_args_a_b(self):
+    def test_default_with_args_a_b(self):
         r =self.app.get('/sub4/default_with_args/a/b')
-        assert "DEFAULT WITH ARGS a b" in r.body, r
+        assert "default with args a b" in r.body, r
+        assert "deprecated" not in r.body
+        import warnings
+        warnings.filterwarnings('ignore', category=DeprecationWarning)
+        r = self.app.get('/sub4/deprecated_default_with_args/a/b')
+        warnings.resetwarnings()
+        assert "deprecated default with args a b" in r.body, r
 
-    def test_defalt_with_query_arg(self):
+    def test_default_with_query_arg(self):
         r =self.app.get('/sub4/default_with_args?a=a')
-        assert "DEFAULT WITH ARGS a None" in r.body, r
+        assert "default with args a None" in r.body, r
+        assert "deprecated" not in r.body
+        import warnings
+        warnings.filterwarnings('ignore', category=DeprecationWarning)
+        r = self.app.get('/sub4/deprecated_default_with_args?a=a')
+        warnings.resetwarnings()
+        assert "deprecated default with args a None" in r.body, r
 
     def test_default_with_validator_fail(self):
         r =self.app.get('/sub5/default_with_args?a=True')
-        assert "FAILURE" in r.body, r
+        assert "failure" in r.body, r
 
     def test_default_with_validator_pass(self):
         r =self.app.get('/sub5/default_with_args?a=66')
-        assert "DEFAULT WITH ARGS AND VALIDATORS 66 None" in r.body, r
+        assert "default with args and validators 66 None" in r.body, r
 
     def test_default_with_validator_pass2(self):
         r =self.app.get('/sub5/default_with_args/66')
-        assert "DEFAULT WITH ARGS AND VALIDATORS 66 None" in r.body, r
+        assert "default with args and validators 66 None" in r.body, r
 
     def test_default_with_validator_fail2(self):
         r =self.app.get('/sub5/default_with_args/True/more')
-        assert "FAILURE" in r.body, r
+        assert "failure" in r.body, r
 
     def test_custom_content_type_in_controller(self):
         resp = self.app.get('/custom_content_type_in_controller')
@@ -599,35 +667,35 @@ class TestTGController(TestWSGIController):
 
     def test_optional_and_req_args(self):
         resp = self.app.get('/optional_and_req_args/test/one')
-        assert """{'three': '3', 'id': 'test', 'two': '2', 'one': 'one'}""" in  resp, resp
+        assert "name=test, one=one, two=2, three=3" in  resp, resp
 
     def test_optional_and_req_args_at_root(self):
         resp = self.app.get('/test_args/test/one')
-        assert """{'three': '3', 'id': 'test', 'two': '2', 'one': 'one'}""" in  resp, resp
+        assert "name=test, one=one, two=2, three=3" in  resp, resp
 
     def test_no_args(self):
         resp = self.app.get('/test_args/test/')
-        assert """{'three': '3', 'id': 'test', 'two': '2', 'one': 'None'}""" in  resp, resp
+        assert "name=test, one=None, two=2, three=3" in  resp, resp
 
     def test_one_extra_arg(self):
         resp = self.app.get('/test_args/test/1')
-        assert """{'three': '3', 'id': 'test', 'two': '2', 'one': '1'}""" in  resp, resp
+        assert "name=test, one=1, two=2, three=3" in  resp, resp
 
     def test_two_extra_args(self):
         resp = self.app.get('/test_args/test/1/2')
-        assert """{'three': '3', 'id': 'test', 'two': '2', 'one': '1'}""" in  resp, resp
+        assert "name=test, one=1, two=2, three=3" in  resp, resp
 
     def test_three_extra_args(self):
         resp = self.app.get('/test_args/test/1/2/3')
-        assert """{'three': '3', 'id': 'test', 'two': '2', 'one': '1'}""" in  resp, resp
+        assert "name=test, one=1, two=2, three=3" in  resp, resp
 
     def test_extra_args_forces_default_lookup(self):
         resp = self.app.get('/test_args/test/1/2/3/4')
-        assert resp.body == """Main Default Page called for url /['test_args', 'test', '1', '2', '3', '4']""", resp
+        assert resp.body == """Main default page called for url /['test_args', 'test', '1', '2', '3', '4']""", resp
 
     def test_not_enough_args(self):
         resp = self.app.get('/test_args/test/1')
-        assert """{'three': '3', 'id': 'test', 'two': '2', 'one': '1'}""" in  resp, resp
+        assert "name=test, one=1, two=2, three=3" in  resp, resp
 
     def test_ticket_2412_with_ordered_arg(self):
         # this is failing
@@ -657,7 +725,7 @@ class TestTGController(TestWSGIController):
     def test_embedded_lookup_with_index_method(self):
         resp = self.app.get('/embedded_lookup_with_index/a/b/method')
         assert 'helper method' in resp, resp
-    
+
     def test_self_calling_lookup_simple_index(self):
         resp = self.app.get('/self_calling')
         assert '((), {})' in resp, resp
